import_array

Function import_array 

pub unsafe fn import_array(
    array: FFI_ArrowArray,
    schema: &FFI_ArrowSchema,
) -> Result<ArrayRef, DataError>
Import a single Arrow array via CDI.

Safety

array and schema must form a valid Arrow C Data Interface pair produced by a compliant exporter. This function takes ownership and will release them.

Errors

Returns DataError::InvalidArgument when the FFI pair cannot be decoded.