pub struct IdRemap { /* private fields */ }Expand description
Dense-id remap produced by TabularData::project.
Maps original (source) variable ids onto contiguous projected ids 0..k-1.
Implementations
Sourceimpl IdRemap
impl IdRemap
Sourcepub fn map(&self, old: VariableId) -> Result<VariableId, DataError>
pub fn map(&self, old: VariableId) -> Result<VariableId, DataError>
Map an original id to its projected dense id.
Errors
DataError::UnknownVariable when old was not included in the projection.