Row selection and column transform helpers shared by estimators / refuters.
SPDX-License-Identifier: MIT OR Apache-2.0
Row selection and column transform helpers shared by estimators / refuters.
SPDX-License-Identifier: MIT OR Apache-2.0